@@ -305,6 +305,19 @@ class LDPViewSetGenerator(ModelViewSet):
         lookup_group = r'\d' if lookup_field == 'pk' else r'[\w\-\.]'
         return r'(?P<{}>{}+)/'.format(lookup_field, lookup_group)
 
+    @classonlymethod
+    def nested_urls(cls, nested_field, view_set=None, **kwargs):
+        '''
+        constructs url patterns for parameterised nested_field
+        :param view_set: an optional CustomViewSet to mixin with the LDPNestedViewSet implementation
+        '''
+        if view_set is not None:
+            class LDPNestedCustomViewSet(LDPNestedViewSet, view_set):
+                pass
+            return LDPNestedCustomViewSet.nested_urls(nested_field, **kwargs)
+
+        return LDPNestedViewSet.nested_urls(nested_field, **kwargs)
+
     @classonlymethod
     def urls(cls, **kwargs):
         '''constructs urls list for model passed in kwargs'''
@@ -322,7 +335,18 @@ class LDPViewSetGenerator(ModelViewSet):
 
         # append nested fields to the urls list
         for field in kwargs.get('nested_fields') or cls.nested_fields:
-            urls.append(url('^' + detail_expr + field + '/', LDPNestedViewSet.nested_urls(field, **kwargs)))
+            # the nested property may have a custom viewset defined
+            try:
+                nested_model = kwargs['model']._meta.get_field(field).related_model
+            except FieldDoesNotExist:
+                nested_model = getattr(kwargs['model'], field).field.model
+
+            if hasattr(nested_model, 'get_view_set'):
+                kwargs['view_set'] = nested_model.get_view_set()
+                urls_fct = kwargs['view_set'].nested_urls # our custom view_set may override nested_urls
+            else:
+                urls_fct = cls.nested_urls
+            urls.append(url('^' + detail_expr + field + '/', urls_fct(field, **kwargs)))
 
         return include(urls)
 
@@ -336,6 +360,7 @@ class LDPViewSet(LDPViewSetGenerator):
     parser_classes = (JSONLDParser,)
     authentication_classes = (NoCSRFAuthentication,)
     filter_backends = [LocalObjectOnContainerPathBackend]
+    write_serializer_class = None
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -346,8 +371,10 @@ class LDPViewSet(LDPViewSetGenerator):
                 if hasattr(p, 'filter_class') and p.filter_class:
                     self.filter_backends.append(p.filter_class)
 
-        self.serializer_class = self.build_read_serializer()
-        self.write_serializer_class = self.build_write_serializer()
+        if self.serializer_class is None:
+            self.serializer_class = self.build_read_serializer()
+        if self.write_serializer_class is None:
+            self.write_serializer_class = self.build_write_serializer()
 
     def build_read_serializer(self):
         model_name = self.model._meta.object_name.lower()
@@ -422,7 +449,7 @@ class LDPViewSet(LDPViewSetGenerator):
         deserializing input, and for serializing output.
         """
         serializer_class = self.get_write_serializer_class()
-        kwargs['context'] = self.get_serializer_context()
+        kwargs.setdefault('context', self.get_serializer_context())
         return serializer_class(*args, **kwargs)
 
     def get_write_serializer_class(self):
